pub async fn fetch_directory_attributes(
url: &str,
) -> Result<Vec<AttributeBlock>, ClientError>Expand description
Fetch and parse the attribute blocks of every item in a directory ($).
pub async fn fetch_directory_attributes(
url: &str,
) -> Result<Vec<AttributeBlock>, ClientError>Fetch and parse the attribute blocks of every item in a directory ($).