pub async fn fetch(url: &str) -> Result<Response, ClientError>Expand description
Fetch a gopher:// URL.
The URL is taken as a string so this signature does not carry a url
major version into the public API.
pub async fn fetch(url: &str) -> Result<Response, ClientError>Fetch a gopher:// URL.
The URL is taken as a string so this signature does not carry a url
major version into the public API.