pub fn parse_attributes(text: &str) -> Vec<AttributeBlock>Expand description
Parse a Gopher+ attribute response into its blocks, in order.
Text before the first block is ignored, and a block with no continuation lines is still a block.
pub fn parse_attributes(text: &str) -> Vec<AttributeBlock>Parse a Gopher+ attribute response into its blocks, in order.
Text before the first block is ignored, and a block with no continuation lines is still a block.